summaryrefslogtreecommitdiffstats
path: root/lib/colonial_twilight/fln_bot_rules.rb
diff options
context:
space:
mode:
Diffstat (limited to 'lib/colonial_twilight/fln_bot_rules.rb')
-rw-r--r--lib/colonial_twilight/fln_bot_rules.rb4
1 files changed, 2 insertions, 2 deletions
diff --git a/lib/colonial_twilight/fln_bot_rules.rb b/lib/colonial_twilight/fln_bot_rules.rb
index 450de2d..4fc6347 100644
--- a/lib/colonial_twilight/fln_bot_rules.rb
+++ b/lib/colonial_twilight/fln_bot_rules.rb
@@ -187,8 +187,8 @@ module ColonialTwilight
# 2) place: underground first unless from map then place active first flipped as underground
# 3) march: underground -> active, unless march would activate then move active first
- # applied as last filter in FLNBot#_place_fln
- def place_guerrillas(spaces)
+ # applied as last filter in FLNBot#_priority
+ def place_guerrillas_priority(spaces)
# 4) support -> with friendly pieces -> random
f = _filter(spaces, &:support?)
_filter(f) { |s| s.guerrillas.positive? }